# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: parnassus_client/proto/arm_stream.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'parnassus_client/proto/arm_stream.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'parnassus_client/proto/arm_stream.proto\x12\narm_stream\x1a\x1cgoogle/protobuf/struct.proto\"4\n\x06Tensor\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05shape\x18\x02 \x03(\x03\x12\r\n\x05\x64type\x18\x03 \x01(\t\"}\n\nEnvRequest\x12\"\n\x05reset\x18\x01 \x01(\x0b\x32\x11.arm_stream.ResetH\x00\x12 \n\x04step\x18\x02 \x01(\x0b\x32\x10.arm_stream.StepH\x00\x12\"\n\x05\x63lose\x18\x03 \x01(\x0b\x32\x11.arm_stream.CloseH\x00\x42\x05\n\x03\x63md\"\x8d\x01\n\x08\x45nvReply\x12\'\n\x05reset\x18\x01 \x01(\x0b\x32\x16.arm_stream.ResetReplyH\x00\x12%\n\x04step\x18\x02 \x01(\x0b\x32\x15.arm_stream.StepReplyH\x00\x12\'\n\x05\x63lose\x18\x03 \x01(\x0b\x32\x16.arm_stream.CloseReplyH\x00\x42\x08\n\x06result\"\x15\n\x05Reset\x12\x0c\n\x04seed\x18\x01 \x03(\x05\"5\n\nResetReply\x12\'\n\x0bobservation\x18\x01 \x01(\x0b\x32\x12.arm_stream.Tensor\"*\n\x04Step\x12\"\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x12.arm_stream.Tensor\"\xce\x01\n\tStepReply\x12\'\n\x0bobservation\x18\x01 \x01(\x0b\x32\x12.arm_stream.Tensor\x12\"\n\x06reward\x18\x02 \x01(\x0b\x32\x12.arm_stream.Tensor\x12&\n\nterminated\x18\x03 \x01(\x0b\x32\x12.arm_stream.Tensor\x12%\n\ttruncated\x18\x04 \x01(\x0b\x32\x12.arm_stream.Tensor\x12%\n\x04info\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x07\n\x05\x43lose\"\x0c\n\nCloseReply2G\n\x06\x41rmEnv\x12=\n\tStreamEnv\x12\x16.arm_stream.EnvRequest\x1a\x14.arm_stream.EnvReply(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'parnassus_client.proto.arm_stream_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TENSOR']._serialized_start=85
  _globals['_TENSOR']._serialized_end=137
  _globals['_ENVREQUEST']._serialized_start=139
  _globals['_ENVREQUEST']._serialized_end=264
  _globals['_ENVREPLY']._serialized_start=267
  _globals['_ENVREPLY']._serialized_end=408
  _globals['_RESET']._serialized_start=410
  _globals['_RESET']._serialized_end=431
  _globals['_RESETREPLY']._serialized_start=433
  _globals['_RESETREPLY']._serialized_end=486
  _globals['_STEP']._serialized_start=488
  _globals['_STEP']._serialized_end=530
  _globals['_STEPREPLY']._serialized_start=533
  _globals['_STEPREPLY']._serialized_end=739
  _globals['_CLOSE']._serialized_start=741
  _globals['_CLOSE']._serialized_end=748
  _globals['_CLOSEREPLY']._serialized_start=750
  _globals['_CLOSEREPLY']._serialized_end=762
  _globals['_ARMENV']._serialized_start=764
  _globals['_ARMENV']._serialized_end=835
# @@protoc_insertion_point(module_scope)
